[![build](https://github.com/TRIQS/triqs_maxent/workflows/build/badge.svg)](https://github.com/TRIQS/triqs_maxent/actions?query=workflow%3Abuild)

# MaxEnt

The goal of this TRIQS application is to provide a modular Maximum Entropy program to perform analytic continuation.

In the spirit of TRIQS, the implementation is not intended as a monolithic package that the user interacts with via input files, but as a set of tools (i.e., functions and classes) that can be called from python.

Learn how to use this package in the [documentation](https://triqs.github.io/maxent).

## Disclaimer

   TRIQS/maxent is a new TRIQS application made public in 2018.
   We have tested the code on multiple problems and made sure
   that the unit tests cover extensive parts of the code.
   However, there is no guarantee that the code is free of bugs.
   Therefore, if you encounter any problems we kindly ask you to
   open an `issue report on github <https://github.com/triqs/maxent/issues>`_.
   Should you run benchmarks and comparison to other analytic continuation
   packages please share your results with us. Any feedback is greatly appreciated.

## Authors

- Gernot J. Kraberger, Graz University of Technology
- Manuel Zingl, CCQ, Flatiron Institute, Simons Foundation and previously Graz University of Technology
